package com.boman.web.core.controller;

import java.util.List;
import com.aliyuncs.dysmsapi.model.v20170525.QuerySendDetailsResponse;
import com.aliyuncs.exceptions.ClientException;
import com.boman.common.core.utils.SecurityUtils;
import com.boman.common.core.utils.StringUtils;
import com.boman.common.core.utils.poi.ExcelUtil;
import com.boman.common.core.web.controller.BaseController;
import com.boman.domain.SysFile;
import com.boman.domain.TableDataInfo;
import com.boman.domain.dto.AjaxResult;
import com.boman.domain.dto.R;
import com.boman.system.api.RemoteFileService;
import com.boman.web.core.service.sendSms.ISendSmsService;
import com.boman.web.core.utils.SendSmsUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.boman.web.core.domain.SendSms;
import org.springframework.web.multipart.MultipartFile;


/**
 * 中考下发短信日志Controller
 *
 * @author boman
 * @date 2022-07-11
 */
@RestController
@RequestMapping("/sendSms")
public class SendSmsController extends BaseController
{
    @Autowired
    private ISendSmsService sendSmsService;


    @Autowired
    private RemoteFileService remoteFileService;

    /**
     * 查询中考下发短信日志列表
     */
    @GetMapping("/list")
    public TableDataInfo list(SendSms sendSms)
    {
        startPage();
        List<SendSms> list = sendSmsService.selectSendSmsList(sendSms);
        return getDataTable(list);
    }


    /**
     * 获取中考下发短信日志详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(sendSmsService.selectSendSmsById(id));
    }

    /**
     * 新增中考下发短信日志
     */
    @PostMapping
    public AjaxResult add(@RequestBody SendSms sendSms)
    {
        return toAjax(sendSmsService.insertSendSms(sendSms));
    }

    /**
     * 修改中考下发短信日志
     */
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody SendSms sendSms)
    {
        return toAjax(sendSmsService.updateSendSms(sendSms));
    }

    /**
     * 删除中考下发短信日志
     */
    @GetMapping(value = "/delete/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(sendSmsService.deleteSendSmsByIds(ids));
    }


    /**
     * 导入发送短信的中考学科成绩数据
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @PostMapping("/importScore")
    public AjaxResult importScore(MultipartFile file, boolean updateSupport) throws Exception
    {
        R<SysFile> fileResult = remoteFileService.upload(file);
        if (StringUtils.isNull(fileResult) || StringUtils.isNull(fileResult.getData()))
        {
            return AjaxResult.error("文件服务异常，请联系管理员");
        }
        String url = fileResult.getData().getUrl();
        System.out.println("中考学科成绩数据文件地址"+url);
        long startTimeSql = System.currentTimeMillis();
        ExcelUtil<SendSms> util = new ExcelUtil<SendSms>(SendSms.class);
        List<SendSms> userList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = sendSmsService.importScore(userList, updateSupport, operName);
        long endTimeSql = System.currentTimeMillis() - startTimeSql;
        System.out.println("执行批量下发短信共:" + endTimeSql + "ms");
        return AjaxResult.success(message);
    }
    /**
     * 导入发送短信的中考录取数据
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        R<SysFile> fileResult = remoteFileService.upload(file);
        if (StringUtils.isNull(fileResult) || StringUtils.isNull(fileResult.getData()))
        {
            return AjaxResult.error("文件服务异常，请联系管理员");
        }
        String url = fileResult.getData().getUrl();
        System.out.println("中考录取数据文件地址"+url);
        long startTimeSql = System.currentTimeMillis();
        ExcelUtil<SendSms> util = new ExcelUtil<SendSms>(SendSms.class);
        List<SendSms> userList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = sendSmsService.importUser(userList, updateSupport, operName);
        long endTimeSql = System.currentTimeMillis() - startTimeSql;
        System.out.println("执行批量下发短信共:" + endTimeSql + "ms");
        return AjaxResult.success(message);
    }

    /**
     *通用导入发送短信通知数据，需要模板编号，手机号
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @PostMapping("/importDataNotice")
    public AjaxResult importDataNotice(MultipartFile file, boolean updateSupport) throws Exception
    {
        long startTimeSql = System.currentTimeMillis();
        ExcelUtil<SendSms> util = new ExcelUtil<SendSms>(SendSms.class);
        List<SendSms> userList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = sendSmsService.importUserNotice(userList, updateSupport, operName);
        long endTimeSql = System.currentTimeMillis() - startTimeSql;
        System.out.println("执行批量下发通知短信模板共:" + endTimeSql + "ms");
        return AjaxResult.success(message);
    }

    /**
     * 单独发送短信的接口
     */
    @PostMapping("/sendSmsOnly")
    public AjaxResult sendSms(@RequestBody SendSms sendSms) {
        String phone = sendSms.getPhone();
        if (StringUtils.isBlank(phone)) {
            return AjaxResult.error("未获取到手机号");
        }
        String templateName = sendSms.getTemplateName();
        if (StringUtils.isBlank(templateName)) {
            return AjaxResult.error("未获取到模板名称");
        }
        try {
            //"{\"name\":\"" + code + "\",\"reportNumber\":\"" + code + "\"}"
            QuerySendDetailsResponse querySendDetailsResponse = SendSmsUtils.sendSmsAndQuery(phone, "{\"ticketId\":\"" + sendSms.getTicketId() + "\",\"name\":\"" + sendSms.getName() + "\",\"result\":\"" + sendSms.getResult() + "\"}", templateName);
            String ok = querySendDetailsResponse.getCode();
            if ("OK".equals(ok)) {
                sendSms.setStatus("发送成功");
                sendSmsService.insertSendSms(sendSms);
                return AjaxResult.success("发送成功");
            } else {
                sendSms.setStatus("发送失败");
                sendSmsService.insertSendSms(sendSms);
                return AjaxResult.error(querySendDetailsResponse.getMessage());
            }
        } catch (ClientException e) {
            e.printStackTrace();
            sendSms.setStatus("发送失败");
            sendSmsService.insertSendSms(sendSms);
        }
        return AjaxResult.error("发送失败");
    }

    /**
     * 导入发送短信的中考信息修改通知数据多线程
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @PostMapping("/importDataNoticeMore")
    public AjaxResult importDataNoticeMore(MultipartFile file, boolean updateSupport) throws Exception
    {
        long startTimeSql = System.currentTimeMillis();
        ExcelUtil<SendSms> util = new ExcelUtil<SendSms>(SendSms.class);
        List<SendSms> userList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = sendSmsService.importUserNoticeMore(userList, updateSupport, operName);
        long endTimeSql = System.currentTimeMillis() - startTimeSql;
        System.out.println("执行批量下发通知短信模板共:" + endTimeSql + "ms");
        return AjaxResult.success(message);
    }

}
