package com.boman.web.core.service;


import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.alibaba.nacos.common.http.HttpUtils;
import com.aliyun.dysmsapi20170525.models.SendBatchSmsRequest;
import com.aliyun.dysmsapi20170525.models.SendBatchSmsResponse;
import com.aliyuncs.http.HttpRequest;
import com.boman.common.core.exception.CustomException;
import com.boman.common.core.utils.DateUtils;
import com.boman.common.core.utils.IdUtils;
import com.boman.common.core.utils.StringUtils;
import com.boman.common.core.utils.number.NumberUtils;
import com.boman.common.core.utils.obj.ObjectUtils;
import com.boman.common.datasource.annotation.Master;
import com.boman.common.redis.service.RedisService;
import com.boman.common.security.service.TokenService;
import com.boman.domain.*;
import com.boman.domain.dto.AjaxResult;
import com.boman.domain.dto.FormDataDto;
import com.boman.system.api.RemoteDeptService;
import com.boman.system.api.RemoteUserService;
import com.boman.web.core.domain.*;
import com.boman.web.core.domain.vo.AccountingDataVo;
import com.boman.web.core.mapper.AccountingDataMapper;
import com.boman.web.core.mapper.CzrkMapper;
import com.boman.web.core.mapper.FireproofDataMapper;
import com.boman.web.core.mapper.GridInfoMapper;
import com.boman.web.core.service.accounting.IAccountingDataService;
import com.boman.web.core.service.birth.BirthRecordsService;
import com.boman.web.core.service.common.ICommonService;
import com.boman.web.core.service.czrk.CzrkServiceImpl;
import com.boman.web.core.service.czrk.ICzrkJzdzService;
import com.boman.web.core.service.ip.IpTimesService;
import com.boman.web.core.service.toQianShan.ToQianshanPersonnerService;
import com.boman.web.core.utils.*;
import lombok.SneakyThrows;
import org.apache.commons.lang3.BooleanUtils;
import org.apache.ibatis.session.ExecutorType;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;

import javax.annotation.Resource;
import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.TimeUnit;

import static com.boman.common.core.utils.obj.ObjectUtils.isEmpty;
import static com.boman.common.core.utils.obj.ObjectUtils.map;
import static com.boman.common.redis.RedisKey.STS_CZRK_;
import static com.boman.domain.constant.AttendanceConst.*;


/**
 * @author tjf
 * @Date: 2021/08/04/17:49
 */
@Component
public class TaskService {

    @Autowired
    private CzrkMapper czrkMapper;
    @Resource
    private RemoteDeptService remoteDeptService;
    @Resource
    private RedisService redisService;
    @Resource
    private ICzrkJzdzService czrkJzdzService;

    @Resource
    private TableServiceCmdService tableServiceCmdService;

    @Resource
    private RemoteUserService remoteUserService;

    @Resource
    private BirthRecordsService birthRecordsService;

    @Resource
    private ICommonService commonService;

    @Resource
    private IAccountingDataService accountingDataService;

    @Resource
    private ToQianshanPersonnerService toQianshanPersonnerService;

    @Resource
    private AccountingDataMapper accountingDataMapper;

    @Resource
    private SqlSessionFactory sqlSessionFactory;

    @Resource
    private FireproofDataMapper fireproofDataMapper;

    private static final String tableName = "attendance_table";

    /**
     * 每月1号往考勤记录表根据用户插入当月的数据 每月一号00:00分
     */
    public void configureTasks() {
        //获取当月每一天
        String date = DateUtils.getDate();
        List<String> monthEveryDays = DateUtils.getMonthEveryDays(date);
        //获取所有用户
        List<SysUser> sysUsers = remoteUserService.selectUserListAll();
        if (sysUsers != null && sysUsers.size() > 0) {
            if (monthEveryDays != null) {
                JSONObject condition = new JSONObject();
                //需要ATTENDANCE_TABLE_TODAYTIME字段是查询可见
                condition.put(ATTENDANCE_TABLE_TODAYTIME, monthEveryDays);
                condition.put(IS_DEL, "N");
                //先去查询是否已经存在当前日期的记录
                List<JSONObject> byMap = commonService.getByMap(tableName, condition);
                if (byMap != null) {
                    List<String> days = new ArrayList<>();
                    for (JSONObject jsonObject : byMap) {
                        String day = jsonObject.get(ATTENDANCE_TABLE_TODAYTIME).toString();
                        days.add(day);
                    }
                    monthEveryDays.removeAll(days);
                }
                for (String monthEveryDay : monthEveryDays) {
                    for (SysUser sysUser : sysUsers) {
                        JSONObject commitData = new JSONObject();
                        commitData.put(ATTENDANCE_USER_NAME, sysUser.getUserName());
                        commitData.put(ATTENDANCE_USER_ID, sysUser.getId());
                        commitData.put(ATTENDANCE_DEPT_ID, sysUser.getDeptId());
                        commitData.put(ATTENDANCE_TABLE_TODAYTIME, monthEveryDay);
                        commitData.put(ATTENDANCE_TABLE_CREATE_TIME, DateUtils.getNowDate());
                        commitData.put(ATTENDANCE_TABLE_CREATE_BY, "admin");
                        FormDataDto dto = new FormDataDto();
                        dto.setObjId(-1L);
                        dto.setTable(tableName);
                        dto.setFixedData(commitData);
                        tableServiceCmdService.objectSave(dto);
                    }
                }
            }
        }
    }

    /**
     * 数据局2024年春节防火短信下发
     */
    public void fireproof() {
        //读取手机号
        List<FireproofData> fireproofData = fireproofDataMapper.selectList();
        if (fireproofData != null && fireproofData.size() > 0) {
            int maxNums = 100; //每次最多发送100条，我们一次批量发100条
            int times = 0;// 循环几个100  用List的长度 除 100
            int size = fireproofData.size(); // 数据数量
            //模板id
            String templateCode = fireproofData.get(0).getTemplateCode();
            //签名
            String SignName = fireproofData.get(0).getSignName();
            List<String> phoneList = new ArrayList<>();
            //List<String> templateList = new ArrayList<>();
            List<String> signNameList = new ArrayList<>();
            StringBuffer signNameJson;
            StringBuffer phoneNumberJson;
            //StringBuffer templateParamJson;
            //返回提示
            String backResult = "";
            if (size < maxNums) {
                times = 1;
            } else {
                times = (size - 1) / maxNums + 1; //为什么要-1 因为如果是200的时候，理论上次数应该是2，而不是3，如果是101，那么次数也是2，这样就保证次数准确。
            }

            for (int j = 0; j < times; j++) {
                if (j > 0 && (j * maxNums + 1 > size)) { //边界判定，如果刚好是100条，那么times的值为2，这时候j 为1的时候 101 大于100结束循环，100条以内不生效
                    break;
                } else {
                    phoneNumberJson = new StringBuffer();
                    signNameJson = new StringBuffer();
                    //templateParamJson = new StringBuffer();
                    phoneNumberJson.append("[");
                    signNameJson.append("[");
                    //templateParamJson.append("[");
                    for (int k = j * maxNums; k < size && k < (j + 1) * maxNums; k++) {
                        // 防止有空行，手机号是必须要有的
                        String phone = fireproofData.get(k).getPhone();
                        if (StringUtils.isEmpty(phone)) {
                            continue;
                        }
                        phoneNumberJson.append("\"" + fireproofData.get(k).getPhone() + "\",");
                        signNameJson.append(SignName+",");
                        //templateParamJson.append("{\"ticketId\":\"" + smsList.get(k).getTicketId() + "\",\"name\":\"" + smsList.get(k).getName() + "\",\"result\":\"" + smsList.get(k).getResult() + "\"},");

                    }
                    phoneNumberJson.deleteCharAt(phoneNumberJson.length() - 1);//移除最后一个逗号字符，
                    signNameJson.deleteCharAt(signNameJson.length() - 1);
                    //templateParamJson.deleteCharAt(templateParamJson.length() - 1);//移除最后一个逗号字符
                    phoneNumberJson.append("]");
                    signNameJson.append("]");
                    //templateParamJson.append("]");
                    phoneList.add(phoneNumberJson.toString());
                    signNameList.add(signNameJson.toString());
                    //templateList.add(templateParamJson.toString());
                }
                //组装请求对象
                if (times == phoneList.size()) {
                    for (int i = 0; i < times; i++) {
                        long startTimeSql = System.currentTimeMillis();
                        SendBatchSmsRequest sendBatchSmsRequest = new SendBatchSmsRequest();
                        //组装电话号码
                        sendBatchSmsRequest.setPhoneNumberJson(phoneList.get(i));
                        //签名名称
                        sendBatchSmsRequest.setSignNameJson(signNameList.get(i));
                        //替换参数
                        //sendBatchSmsRequest.setTemplateParamJson(templateList.get(i));
                        //固定的模板名称
                        sendBatchSmsRequest.setTemplateCode(templateCode);
                        long endTimeSql = System.currentTimeMillis() - startTimeSql;
                        System.out.println("线程" + Thread.currentThread().getId() + "执行批量下发短信通知计算:" + (i + 1) + "次,时间" + endTimeSql + "ms");
                        long startTimeSend = System.currentTimeMillis();
                        SendBatchSmsResponse sendBatchSmsResponse = SendBatchSmsUtils.sendBatchSms(sendBatchSmsRequest);
                        long endTimeSend = System.currentTimeMillis() - startTimeSend;
                        System.out.println("线程" + Thread.currentThread().getId() + "执行批量下发短信通知接口请求:" + (i + 1) + "次,时间" + endTimeSend + "ms");
                        SendSms sendSms = new SendSms();
                        if (sendBatchSmsResponse != null) {
                            String code = sendBatchSmsResponse.getBody().getCode();
                            if (sendBatchSmsResponse.getBody().getCode() != null && "OK".equals(code)) {
                                //批量请求发送短信成功
                                System.out.println("批量短信发送成功：" + phoneList.get(i).split(",").length + "条");
                                backResult = backResult + "第" + i + "次批量成功  ";
                            } else {
                                System.out.println("批量短信发送失败！");
                                backResult = backResult + "第" + i + "次批量失败  ";
                            }
                        }
                    }
                }
            }
        }
    }

    /***
     * 定时执行首页数据任务（每天凌晨1点执行）
     * (cron = "0 0 1 * * ?")
     */
    @Scheduled(cron = "0 0 1 * * ?")
    public void execute() {
        //将每个deptId(潜山市，乡镇，村)的首页都存入redis
        JSONObject results = new JSONObject(16);
        JSONObject resultz = new JSONObject(16);
        JSONObject resultc = new JSONObject(16);
        String startTime = DateUtils.getTodayStartStr();
        String endTime = DateUtils.getTodayEndStr();

        Timestamp s = Timestamp.valueOf(startTime);
        Timestamp e = Timestamp.valueOf(endTime);
        //潜山市
        List<SysDept> allDepts = remoteDeptService.listChildrenDepts(1L);
        results.put("dqdw", "潜山市");
        //所有乡镇集合
        List<SysDept> townsDepts = new ArrayList<>(16);

        for (SysDept allDept : allDepts) {
            if (isEmpty(allDept.getParentId())) {
                continue;
            }
            if (allDept.getParentId() == (1L)) {
                townsDepts.add(allDept);
            }
        }
        results.put("zhen", townsDepts.size()); // 镇的数量

        //所有村集合
        List<SysDept> cunDepts = new ArrayList<>(16);
        for (SysDept townsDept : townsDepts) {
            for (SysDept allDept : allDepts) {
                if (isEmpty(allDept.getParentId())) continue;
                if (townsDept.getId().equals(allDept.getParentId())) {
                    cunDepts.add(allDept);
                }
            }
        }
        results.put("cun", isEmpty(cunDepts) ? 0 : cunDepts.size());
        //查找潜山市户籍人口总数
        List<Czrk> czrkList = czrkMapper.getAllCzrkRegionIdHj("340882000000");
        if (czrkList == null) {
            czrkList = new ArrayList<>();
        }
        //潜山市户籍人口总数
        int hjzrs = czrkList.size();

        //潜山市 户籍人口今日新增
        int hjxz = 0;
        //潜山市 户籍人口今日减少
        int hjjs = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (Czrk czrk : czrkList) {
            if (!"1".equals(czrk.getStatus())) {
                hjzrs--;
            }
            //判断是否是在今天操作的人员信息
            if (s.before(czrk.getUpdateTime()) && czrk.getUpdateTime().before(e)) {
                if (!"1".equals(czrk.getStatus())) {
                    hjjs++;
                } else {
                    hjxz++;
                }
            }
        }
        //潜山市总人数
        results.put("hjzrs", hjzrs);
        //潜山市新增
        results.put("hjxz", hjxz);
        //潜山市减少
        results.put("hjjs", hjjs);

        results.put("hjbfb", NumberUtils.percent(hjzrs, hjzrs));

        //查找潜山市常驻人口信息
        List<CzrkJzdz> czrkJzdzList = czrkJzdzService.selectCzrkJzdzListByRegionId("340882000000");
        if (czrkJzdzList == null) {
            czrkJzdzList = new ArrayList<>();
        }
        //潜山市居住人口总数
        int czzrs = czrkJzdzList.size();

        //潜山市居住人口今日新增
        int czxz = 0;
        //潜山市居住人口今日减少
        int czjs = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (CzrkJzdz czrkJzdz : czrkJzdzList) {
            if ("N".equals(czrkJzdz.getStatus())) {
                czzrs--;
            }
            //判断是否是在今天操作的人员信息
            if (s.before(czrkJzdz.getUpdateTime()) && czrkJzdz.getUpdateTime().before(e)) {
                if ("N".equals(czrkJzdz.getStatus())) {
                    czjs++;
                } else {
                    czxz++;
                }
            }
        }
        //潜山市总人数
        results.put("czzrs", czzrs);
        //潜山市新增
        results.put("czxz", czxz);
        //潜山市减少
        results.put("czjs", czjs);
        results.put("czbfb", NumberUtils.percent(czzrs, czzrs));


        /*List<Long> deptIdList = null;
        int zrs = czrkMapper.countAll(); // 总人数
        int hjzrs = czrkMapper.countHj1(deptIdList); // 该镇户籍人口总数
        //潜山市总人数
        results.put("hjzrs", hjzrs);
        int hjxz = czrkMapper.countByHjXz1(startTime, endTime, deptIdList); // 该镇 户籍人口今日新增
        //潜山市新增
        results.put("hjxz", hjxz);
        int hjjs = czrkMapper.countByHjJs1(startTime, endTime, deptIdList); // 该镇 户籍人口今日减少
        results.put("hjjs", hjjs);
        results.put("hjbfb", NumberUtils.percent(hjzrs, zrs));*/

        /*int czzrs = czrkMapper.countCz1(deptIdList);  // 该镇常住人口总数
        results.put("czzrs", czzrs);
        int czxz = czrkMapper.countByCzXz1(startTime, endTime, deptIdList); // 该镇 常住人口今日新增
        int czjs = czrkMapper.countByCzJs1(startTime, endTime, deptIdList); // 该镇 常住人口今日减少
        results.put("czxz", czxz);
        results.put("czjs", czjs);
        results.put("czbfb", NumberUtils.percent(czzrs, zrs));*/

        // 以各个镇为单位单独处理 townsDepts
        ArrayList<JSONObject> towsDataList = new ArrayList<>(20);

        //czrkList  czrkJzdzList
        for (SysDept townsDept : townsDepts) {
            JSONObject townsResult = new JSONObject(16);
            townSts(townsResult, townsDept, czrkList, czrkJzdzList, hjzrs, czzrs);
            towsDataList.add(townsResult);
        }

        results.put("townDatas", towsDataList);
//                redisService.setCacheObject(packRedisKey(deptId + ""), result, 1L, TimeUnit.DAYS);
        setIntoRedis(packRedisKey(1L + ""), results);
        //QIANSHANSHI = result;


        //镇数据存入redis
        for (SysDept townsDept : townsDepts) {
            townSts(resultz, townsDept, czrkList, czrkJzdzList, hjzrs, czzrs);
//                redisService.setCacheObject(packRedisKey("town:" + deptId), result, 1L, TimeUnit.DAYS);
            setIntoRedis(packRedisKey("town:" + townsDept.getId()), resultz);
        }

        //村数据存入redis
        for (SysDept cunDept : cunDepts) {
            Long deptId = cunDept.getId();
            String deptName = cunDept.getDeptName();
            String areaId = cunDept.getAreaId();
            resultc.put("dqdw", deptName);

            //查找村的数据
            if (czrkList == null) {
                czrkList = new ArrayList<>();
            }
            //该村户籍人口总数
            int hjzrsc = 0;

            //该村 户籍人口今日新增
            int hjxzc = 0;
            //该村 户籍人口今日减少
            int hjjsc = 0;

            //循环所有人判断当前总人数，该村 户籍人口今日新增，该镇 户籍人口今日减少
            for (Czrk czrk : czrkList) {
                if (StringUtils.isNotEmpty(czrk.getVillageId()) && czrk.getVillageId().equals(areaId)) {
                    if ("1".equals(czrk.getStatus())) {
                        hjzrsc++;
                    }
                    //判断是否是在今天操作的人员信息
                    if (s.before(czrk.getUpdateTime()) && czrk.getUpdateTime().before(e)) {
                        if (!"1".equals(czrk.getStatus())) {
                            hjjsc++;
                        } else {
                            hjxzc++;
                        }
                    }
                }
            }
            resultc.put("hjzrs", hjzrsc);
            resultc.put("hjxz", hjxzc);
            resultc.put("hjjs", hjjsc);
            resultc.put("hjbfb", NumberUtils.percent(hjzrs, czzrs));


            if (czrkJzdzList == null) {
                czrkJzdzList = new ArrayList<>();
            }
            //该镇户籍人口总数
            int czzrsc = 0;

            //该镇 户籍人口今日新增
            int czxzc = 0;
            //该镇 户籍人口今日减少
            int czjsc = 0;

            //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
            for (CzrkJzdz czrkJzdz : czrkJzdzList) {
                if (StringUtils.isNotEmpty(czrkJzdz.getVillageId()) && czrkJzdz.getVillageId().equals(areaId)) {
                    if ("Y".equals(czrkJzdz.getStatus())) {
                        czzrsc++;
                    }
                    //判断是否是在今天操作的人员信息
                    if (s.before(czrkJzdz.getUpdateTime()) && czrkJzdz.getUpdateTime().before(e)) {
                        if ("N".equals(czrkJzdz.getStatus())) {
                            czjsc++;
                        } else {
                            czxzc++;
                        }
                    }
                }

            }
            resultc.put("czzrs", czzrsc);
            resultc.put("czxz", czxzc);
            resultc.put("czjs", czjsc);
            resultc.put("czbfb", NumberUtils.percent(czzrs, czzrs));



            /*List<SysDept> depts = remoteDeptService.listChildrenDepts(deptId);
            resultc.put("dqdw", deptName);
            List<Long> cdeptIdList = map(depts, SysDept::getId);
            int zrsc = czrkMapper.countAll(); // 总人数
            int hjzrsc = czrkMapper.countHj1(cdeptIdList); // 该镇户籍人口总数
            resultc.put("hjzrs", hjzrsc);
            int hjxzc = czrkMapper.countByHjXz1(startTime, endTime, cdeptIdList); // 该镇 户籍人口今日新增
            resultc.put("hjxz", hjxzc);
            int hjjsc = czrkMapper.countByHjJs1(startTime, endTime, cdeptIdList); // 该镇 户籍人口今日减少
            resultc.put("hjjs", hjjsc);
            resultc.put("hjbfb", NumberUtils.percent(hjzrs, zrs));

            int czzrsc = czrkMapper.countCz1(cdeptIdList);  // 该镇常住人口总数
            resultc.put("czzrs", czzrsc);
            int czxzc = czrkMapper.countByCzXz1(startTime, endTime, cdeptIdList); // 该镇 常住人口今日新增
            int czjsc = czrkMapper.countByCzJs1(startTime, endTime, cdeptIdList); // 该镇 常住人口今日减少
            resultc.put("czxz", czxzc);
            resultc.put("czjs", czjsc);
            resultc.put("czbfb", NumberUtils.percent(czzrsc, zrsc));*/
            setIntoRedis(packRedisKey("village:" + deptId), resultc);
        }


        System.out.println("定时任务");
    }

    private void townSts(JSONObject result, SysDept sysDept, List<Czrk> czrkList, List<CzrkJzdz> czrkJzdzList, int shjzrs, int sczzrs) {
        String startTime = DateUtils.getTodayStartStr();
        String endTime = DateUtils.getTodayEndStr();
        Timestamp s = Timestamp.valueOf(startTime);
        Timestamp e = Timestamp.valueOf(endTime);
        Long deptId = sysDept.getId();
        String deptName = sysDept.getDeptName();
        String areaId = sysDept.getAreaId();
        // 乡镇以下的所有部门
        List<SysDept> depts = remoteDeptService.listChildrenDepts(deptId);
        List<SysDept> cunDepts = new ArrayList<>(16);
        for (SysDept dept : depts) {
            if (isEmpty(dept.getParentId())) continue;
            if (deptId.equals(dept.getParentId())) {
                cunDepts.add(dept);
            }
        }
        result.put("cun", isEmpty(cunDepts) ? 0 : cunDepts.size());

        List<SysDept> zuDept = new ArrayList<>(16);
        for (SysDept cunDept : cunDepts) {
            for (SysDept dept : depts) {
                if (cunDept.getId().equals(dept.getParentId())) {
                    zuDept.add(dept);
                }
            }
        }

        result.put("zu", isEmpty(zuDept) ? 0 : zuDept.size());

        /** **/
        /*int zrs = 0; // 总人数
        if (BooleanUtils.isTrue(percent)) {
            zrs = czrkMapper.countAll();
        }*/

        if (czrkList == null) {
            czrkList = new ArrayList<>();
        }
        //该镇户籍人口总数
        int hjzrs = 0;

        //该镇 户籍人口今日新增
        int hjxz = 0;
        //该镇 户籍人口今日减少
        int hjjs = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (Czrk czrk : czrkList) {
            if (StringUtils.isNotEmpty(czrk.getVillageTownsId()) && String.valueOf(czrk.getVillageTownsId()).equals(areaId)) {
                if ("1".equals(czrk.getStatus())) {
                    hjzrs++;
                }
                //判断是否是在今天操作的人员信息
                if (s.before(czrk.getUpdateTime()) && czrk.getUpdateTime().before(e)) {
                    if (!"1".equals(czrk.getStatus())) {
                        hjjs++;
                    } else {
                        hjxz++;
                    }
                }
            }
        }
        result.put("hjzrs", hjzrs);
        result.put("hjxz", hjxz);
        result.put("hjjs", hjjs);
        result.put("hjbfb", NumberUtils.percent(hjzrs, shjzrs));


        if (czrkJzdzList == null) {
            czrkJzdzList = new ArrayList<>();
        }
        //该镇户籍人口总数
        int czzrs = 0;

        //该镇 户籍人口今日新增
        int czxz = 0;
        //该镇 户籍人口今日减少
        int czjs = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (CzrkJzdz czrkJzdz : czrkJzdzList) {
            if (StringUtils.isNotEmpty(czrkJzdz.getTownId()) && czrkJzdz.getTownId().equals(areaId)) {
                if ("Y".equals(czrkJzdz.getStatus())) {
                    czzrs++;
                }
                //判断是否是在今天操作的人员信息
                if (s.before(czrkJzdz.getUpdateTime()) && czrkJzdz.getUpdateTime().before(e)) {
                    if ("N".equals(czrkJzdz.getStatus())) {
                        czjs++;
                    } else {
                        czxz++;
                    }
                }
            }

        }
        result.put("czzrs", czzrs);
        result.put("czxz", czxz);
        result.put("czjs", czjs);
        result.put("czbfb", NumberUtils.percent(czzrs, sczzrs));

        /*int czzrs = czrkMapper.countCz1(deptIdList);  // 该镇常住人口总数
        result.put("czzrs", czzrs);
        int czxz = czrkMapper.countByCzXz1(startTime, endTime, deptIdList); // 该镇 常住人口今日新增
        int czjs = czrkMapper.countByCzJs1(startTime, endTime, deptIdList); // 该镇 常住人口今日减少
        result.put("czxz", czxz);
        result.put("czjs", czjs);
        result.put("czbfb", NumberUtils.percent(czzrs, zrs));*/

        result.put("zhen", deptName);
        /** **/


        // 常住人口信息
//        int type = 4; // 乡镇
//        int czzrs = czrkMapper.countCzrk(type, areaId); // 常住人口
//        result.put("czzrs", czzrs);
//
//        int zrs = 0;
//        // 常住人口占总人口的百分比
//        if (BooleanUtils.isTrue(percent)) {
//             // 查全部
//            zrs = czrkMapper.countCzrk(type, areaId);
//            String czbfb = NumberUtils.percent(czzrs, zrs);
//            result.put("czbfb", czbfb);
//        }
//
////        type = 4;
//        int czxz = czrkMapper.countByCzXz(startTime, endTime, type, areaId);
//        int czjs = czrkMapper.countByCzJs(startTime, endTime, type, areaId);
//        result.put("czxz", czxz);
//        result.put("czjs", czjs);
//
//        result.put("zhen", deptName);
//
//        // 户籍人口信息
//        int hjxz = czrkMapper.countByHjXz(startTime, endTime, type, areaId); // 新增
//        int hjjs = czrkMapper.countByHjJs(startTime, endTime, type, areaId);// 减少
//        result.put("hjxz", hjxz);
//        result.put("hjjs", hjjs);
//
//        // 户籍总人数
//        int hjzrs = czrkMapper.countHj(startTime, endTime, type, areaId);
////                int hjzrs= isEmpty(hjzrsList) ? 0 : hjzrsList.size();
//        result.put("hjzrs", hjzrs);
//        String hjbfb = NumberUtils.percent(hjzrs, zrs);
//        result.put("hjbfb", hjbfb);
    }

    private void setIntoRedis(String key, Object result) {
        redisService.setCacheObject(key, result, 1L, TimeUnit.DAYS);
    }

    private String packRedisKey(String deptId) {
        return STS_CZRK_ + deptId + ":" + DateUtils.getDate();
    }

    /***
     * 新生儿（每天18点执行）
     *
     */
    @Scheduled(cron = "0 0 18 * * ?")
    public void getNewborn() {

        String token = getToken();


        if (StringUtils.isNotBlank(token)) {

            String startTime = redisService.getCacheObject("startTimeNew");
            if (StringUtils.isEmpty(startTime)) {
                startTime = "2022-04-01 00:00:00.0";
            }
            String endTime = DateUtils.formatString(new Date());
            redisService.setCacheObject("startTimeNew", endTime);
            endTime = endTime.replace(" ", "%20");
            startTime = startTime.replace(" ", "%20");

            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("client_id", "acdf50bd13be4901b64c62b1fee862c0");
            paramMap.put("access_token", token);
            paramMap.put("xzqh", "潜山市");
            paramMap.put("start_time", startTime);
            paramMap.put("end_time", endTime);
            String http = "http://60.171.171.235:9090/service/api/rkk/qxcsyxzmcx";
            try {
                String data = HttpClientUtils.doGet(http, paramMap);

                List<BirthRecords> birthRecordsList = JSONObject.parseArray(data, BirthRecords.class);
                for (BirthRecords birthRecords : birthRecordsList) {
                    birthRecords.setIsDel("N");
                    birthRecords.setCreateBy("系统");
                    birthRecords.setUpdateBy("系统");
                    birthRecords.setStatus(1);
                }
                //保存
                for (BirthRecords birthRecords : birthRecordsList) {
                    //判断数据库是否存在数据
                    int num = birthRecordsService.selectBirthRecordsByCsyxzmbh(birthRecords.getCsyxzmbh());
                    if (num < 1) {
                        birthRecordsService.insertBirthRecords(birthRecords);
                    }
                }
                System.out.println(data);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    /***
     * 新生儿（手动跑数据，时间间隔一个月）
     *
     */
    public void getNewbornS(String startTime, String endTime) {

        String token = getToken();

        if (StringUtils.isNotBlank(token)) {

            endTime = endTime.replace(" ", "%20");
            startTime = startTime.replace(" ", "%20");

            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("client_id", "acdf50bd13be4901b64c62b1fee862c0");
            paramMap.put("access_token", token);
            paramMap.put("xzqh", "潜山市");
            paramMap.put("start_time", startTime);
            paramMap.put("end_time", endTime);
            String http = "http://60.171.171.235:9090/service/api/rkk/qxcsyxzmcx";
            try {
                String data = HttpClientUtils.doGet(http, paramMap);

                List<BirthRecords> birthRecordsList = JSONObject.parseArray(data, BirthRecords.class);
                for (BirthRecords birthRecords : birthRecordsList) {
                    birthRecords.setIsDel("N");
                    birthRecords.setCreateBy("系统");
                    birthRecords.setUpdateBy("系统");
                    birthRecords.setStatus(1);
                }
                //保存
                for (BirthRecords birthRecords : birthRecordsList) {
                    //判断数据库是否存在数据
                    int num = birthRecordsService.selectBirthRecordsByCsyxzmbh(birthRecords.getCsyxzmbh());
                    if (num < 1) {
                        birthRecordsService.insertBirthRecords(birthRecords);
                    }
                }
                System.out.println(data);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }


    /**
     * 获取政务网token
     */
    public String getToken() {
        String token = "";
        Map<String, String> paramMap = new HashMap<>();
        paramMap.put("client_id", "acdf50bd13be4901b64c62b1fee862c0");
        paramMap.put("client_secret", "a3650d67fc034b2d8ea259182b3d99f3");
        String http = "http://60.171.171.235:9090/oauth/token";
        try {
            String data = HttpClientUtils.doGet(http, paramMap);
            JSONObject jsonObject = JSONObject.parseObject(data);
            token = jsonObject.getString("access_token");
        } catch (IOException e) {
            e.printStackTrace();
        }
        return token;
    }

    /**
     * 抓取核酸数据每10分钟抓取一次,新增到accounting_data
     */
    //@Scheduled(cron = "0 0/10 * * * ? ")
    public void insertAccountingData() {
        String token = getToken();
        if (StringUtils.isNotBlank(token)) {
            String startTime = "2022-05-14 00:00:00.0";
            //去数据库取最新的一条数据
            AccountingDataVo accountingData = accountingDataService.getAccountingDataOne();
            if (accountingData != null) {
                startTime = accountingData.getCjsj();
                Date parse = DateUtil.parse(startTime);
                Date parseNew = DateUtil.offsetSecond(parse, 1);
                startTime = DateUtil.format(parseNew, "yyyy-MM-dd HH:mm:ss");
            }
            //String startTime = redisService.getCacheObject("startTime");
            //String startTime = "2022-05-14 10:47:00.0";
            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("client_id", "acdf50bd13be4901b64c62b1fee862c0");
            paramMap.put("access_token", token);
            paramMap.put("sfzhm", "");
            if (StringUtils.isBlank(startTime)) {
                //第一次抓取当前时间到之前的10分钟的数据
                Date nowDate = DateUtils.getNowDate();
                SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                String endTime = format.format(nowDate);
                startTime = DateUtils.plusSeconds(endTime, 10);
                redisService.setCacheObject("startTime", endTime);
            }
            String endTime = DateUtils.formatString(new Date());
            redisService.setCacheObject("startTime", endTime);
            endTime = endTime.replace(" ", "%20");
            startTime = startTime.replace(" ", "%20");
            paramMap.put("start_time", startTime);
            paramMap.put("end_time", endTime);
            String http = "http://60.171.171.235:9090/service/api/wjw/qshssjsjc";
            try {
                String data = HttpClientUtils.doGet(http, paramMap);

                if (StringUtils.isNotBlank(data)) {
                    List<AccountingDataVo> list = JSONObject.parseArray(data, AccountingDataVo.class);
                    if (list != null && list.size() > 0) {
                        //插入数据
                        //accountingDataService.insertAccountingData(list);
                    }
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    //@Scheduled(cron = "0 0/20 * * * ? ")
    public void thirdNucleicAcid() {
        String startTime = redisService.getCacheObject("startTime");
        if (StringUtils.isEmpty(startTime)) {
            startTime = "2022-05-14 00:00:00";
        }
        //开始时间往后推20分钟
        String endTime = DateUtils.plusSeconds(startTime, 20);

        accountingDataService.thirdNucleicAcid(startTime, endTime);

        redisService.setCacheObject("startTime", endTime);

    }


    /***
     * 核酸补充数据定时任务（每天3点执行）
     */
    //@Scheduled(cron = "0 0 3 * * ? ")
    public void supplement() {
        //获取当前时间
        Date data = DateUtils.getNowDate();
        String endTime = DateUtils.formatString(data);
        //当前时间往前推一个星期（10080分钟）
        String startTime = DateUtils.plusSeconds(endTime, -10080);

        accountingDataService.thirdNucleicAcid(startTime, endTime);

    }


    /***
     *  匹配核酸和户籍数据
     */
    public void pphshj() {
        //String startTime = "2022-05-14 00:00:00.0";
        String startTime = redisService.getCacheObject("startTime");
        if (StringUtils.isBlank(startTime)) {
            startTime = "2022-05-14 00:00:00.0";
        }

        Date parse = DateUtil.parse(startTime);
        Date parseNew = DateUtil.offsetSecond(parse, 600);
        String endTime = DateUtil.format(parseNew, "yyyy-MM-dd HH:mm:ss");
        redisService.setCacheObject("startTime", endTime);

        System.out.println("batchInsert 查询数据开始========");
        long start1 = System.currentTimeMillis();
        //获取所有核酸数据源
        List<TSampling514> TSampling514List = accountingDataService.getTSampling514AllData(startTime, endTime);
        //获取所有户籍数据
        //List<Czrk> czrks = czrkMapper.listByCzrk(new Czrk());

        long end1 = System.currentTimeMillis();
        System.out.println("---------------查询数据耗时" + (end1 - start1) + "---------------");

        //List<Czrk> czrkList = new ArrayList<>();
        System.out.println("batchInsert 循环数据开始========");
        long start2 = System.currentTimeMillis();
        for (TSampling514 tSampling514 : TSampling514List) {
            if (tSampling514.getCollectTime() != null) {
                Czrk czrk = new Czrk();
                czrk.setNucleicAcidTime(String.valueOf(tSampling514.getCollectTime()));
                czrk.setIdCard(tSampling514.getIdCard());
                czrkMapper.updateCzrkByNucleicAcid(czrk);
                //czrkList.add(czrk);
            }

        }

        long end2 = System.currentTimeMillis();
        System.out.println("---------------循环数据耗时" + (end2 - start2) + "---------------");
    }


    public void pphshjNo() {

        System.out.println("batchInsert 查询数据开始========");
        long start1 = System.currentTimeMillis();
        //获取所有核酸数据源
        List<TSampling514> TSampling514List = accountingDataService.getTSampling514AllDataNoTime();
        //获取所有户籍数据
        //List<Czrk> czrks = czrkMapper.listByCzrk(new Czrk());

        long end1 = System.currentTimeMillis();
        System.out.println("---------------查询数据耗时" + (end1 - start1) + "---------------");

        //List<Czrk> czrkList = new ArrayList<>();
        System.out.println("batchInsert 循环数据开始========");
        long start2 = System.currentTimeMillis();
        for (TSampling514 tSampling514 : TSampling514List) {
            Czrk czrk = new Czrk();
            czrk.setNucleicAcidTime("-");
            czrk.setIdCard(tSampling514.getIdCard());
            czrkMapper.updateCzrkByNucleicAcid(czrk);
            //czrkList.add(czrk);

        }

        long end2 = System.currentTimeMillis();
        System.out.println("---------------循环数据耗时" + (end2 - start2) + "---------------");
    }


    //统计镇数据（暂时用）
    public AjaxResult zhenDate(String startTime, String endTime) {

        long start2 = System.currentTimeMillis();

        List<SysDept> allDepts = remoteDeptService.listChildrenDepts(1L);

        //所有乡镇集合
        List<SysDept> townsDepts = new ArrayList<>(16);

        for (SysDept allDept : allDepts) {
            if (isEmpty(allDept.getParentId())) {
                continue;
            }
            if (allDept.getParentId() == (1L)) {
                townsDepts.add(allDept);
            }
        }

        ArrayList<JSONObject> towsDataList = new ArrayList<>(20);
        for (SysDept townsDept : townsDepts) {
            JSONObject townsResult = new JSONObject(16);
            //查询镇数据
            //户籍人员数据
            int hjz = accountingDataService.tongjiHjZ(startTime, endTime, townsDept.getAreaId());
            //常住人员数据
            int czz = accountingDataService.tongjiCzZ(startTime, endTime, townsDept.getAreaId());
            townsResult.put("name", townsDept.getDeptName());
            townsResult.put("hjz", hjz);
            townsResult.put("czz", czz);
            towsDataList.add(townsResult);
        }
        long end2 = System.currentTimeMillis();
        System.out.println("---------------循环数据耗时" + (end2 - start2) + "---------------");
        return AjaxResult.success(towsDataList);
    }

    //统计镇，村数据（暂时用）
    public AjaxResult cunDate(String startTime, String endTime) {

        long start2 = System.currentTimeMillis();

        List<SysDept> allDepts = remoteDeptService.listChildrenDepts(1L);

        //所有乡镇集合
        List<SysDept> townsDepts = new ArrayList<>(16);

        for (SysDept allDept : allDepts) {
            if (isEmpty(allDept.getParentId())) {
                continue;
            }
            if (allDept.getParentId() == (1L)) {
                townsDepts.add(allDept);
            }
        }

        ArrayList<JSONObject> towsDataList = new ArrayList<>(20);
        for (SysDept townsDept : townsDepts) {
            JSONObject townsResult = new JSONObject(16);
            //查询镇数据
            //户籍人员数据
            int hjz = accountingDataService.tongjiHjZ(startTime, endTime, townsDept.getAreaId());
            //常住人员数据
            int czz = accountingDataService.tongjiCzZ(startTime, endTime, townsDept.getAreaId());
            townsResult.put("name", townsDept.getDeptName());
            townsResult.put("hjz", hjz);
            townsResult.put("czz", czz);
            //获取镇下面的村数据
            List<SysDept> cunDepts = new ArrayList<>(16);

            for (SysDept allDept : allDepts) {
                if (isEmpty(allDept.getParentId())) {
                    continue;
                }
                if (allDept.getParentId() == Long.valueOf(townsDept.getId())) {
                    cunDepts.add(allDept);
                }
            }

            ArrayList<JSONObject> cunDataList = new ArrayList<>(20);
            for (SysDept cunDept : cunDepts) {
                JSONObject cunResult = new JSONObject(16);
                //查询村数据
                //户籍人员数据
                int hjc = accountingDataMapper.tongjiHjC(startTime, endTime, cunDept.getAreaId());
                //常住人员数据
                int czc = accountingDataMapper.tongjiCzC(startTime, endTime, cunDept.getAreaId());
                cunResult.put("name", cunDept.getDeptName());
                cunResult.put("hjc", hjc);
                cunResult.put("czc", czc);
                cunDataList.add(cunResult);
            }
            townsResult.put("cunDataList", cunDataList);
            towsDataList.add(townsResult);
        }
        long end2 = System.currentTimeMillis();
        System.out.println("---------------循环数据耗时" + (end2 - start2) + "---------------");
        return AjaxResult.success(towsDataList);
    }


    /***
     * 核酸统计(每一个小时跑一次)
     */
    //@Scheduled(cron = "0 0 * * * ? ")
    public void nucleicAcidStatistics() {

        System.out.println("batchInsert 核酸统计开始开始========");
        long start = System.currentTimeMillis();
        //潜山市
        JSONObject resultsS = new JSONObject(16);
        //镇
        JSONObject resultsZ = new JSONObject(16);
        //村
        JSONObject resultsC = new JSONObject(16);

        //SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        //SysDept dept = sysUser.getDept();

        List<SysDept> allDepts = remoteDeptService.listChildrenDepts(1L);
        //查找户籍人口总数
        List<Czrk> czrkList = czrkMapper.getAllCzrkRegionId("340882000000");

        //所有乡镇集合
        List<SysDept> townsDepts = new ArrayList<>(16);

        for (SysDept allDept : allDepts) {
            if (isEmpty(allDept.getParentId())) {
                continue;
            }
            if (allDept.getParentId() == (1L)) {
                townsDepts.add(allDept);
            }
        }

        // 以各个镇为单位单独处理 townsDepts
        ArrayList<JSONObject> towsDataList = new ArrayList<>(20);
        for (SysDept townsDept : townsDepts) {
            JSONObject townsResult = new JSONObject(16);
            townStsvaccine(townsResult, townsDept, czrkList);
            towsDataList.add(townsResult);
        }

        resultsS.put("townDatas", towsDataList);
        resultsS.put("type", "1");

        redisService.setCacheObject("1", resultsS);


        //获取镇数据
        for (SysDept townsDept : townsDepts) {

            //所有乡镇集合
            List<SysDept> cunDepts = new ArrayList<>(16);

            for (SysDept allDept : allDepts) {
                if (isEmpty(allDept.getParentId())) {
                    continue;
                }
                if (allDept.getParentId() == Long.valueOf(townsDept.getId())) {
                    cunDepts.add(allDept);
                }
            }

            ArrayList<JSONObject> cunDataList = new ArrayList<>(20);

            for (SysDept cunDept : cunDepts) {
                JSONObject townsResult = new JSONObject(16);
                townStsvaccineCun(townsResult, cunDept, czrkList);
                cunDataList.add(townsResult);
            }

            resultsZ.put("townDatas", cunDataList);
            resultsZ.put("type", "2");

            redisService.setCacheObject(townsDept.getAreaId(), resultsZ);
        }
        long end = System.currentTimeMillis();
        System.out.println("---------------核酸统计耗时" + (end - start) + "---------------");

    }

    private void townStsvaccine(JSONObject result, SysDept sysDept, List<Czrk> czrkList) {
        String deptName = sysDept.getDeptName();
        String areaId = sysDept.getAreaId();

        if (czrkList == null) {
            czrkList = new ArrayList<>();
        }

        //该镇户籍人口总数
        int hjzrs = 0;

        //该镇 接种人员数据
        int hjymjz = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (Czrk czrk : czrkList) {
            if (StringUtils.isNotEmpty(czrk.getVillageTownsIdXjd()) && String.valueOf(czrk.getVillageTownsIdXjd()).equals(areaId)) {
                if ("1".equals(czrk.getStatus())) {
                    hjzrs++;
                }

                if ("Y".equals(czrk.getIsNucleicAcid())) {
                    hjymjz++;
                }
            }
        }
        result.put("hjzrs", hjzrs);
        result.put("hjymjz", hjymjz);
        result.put("hjbfb", NumberUtils.percent(hjymjz, hjzrs));
        result.put("name", deptName);
    }

    private void townStsvaccineCun(JSONObject result, SysDept sysDept, List<Czrk> czrkList) {

        ArrayList<JSONObject> towsDataList = new ArrayList<>(20);
        JSONObject resultsC = new JSONObject(16);

        String deptName = sysDept.getDeptName();
        String areaId = sysDept.getAreaId();

        if (czrkList == null) {
            czrkList = new ArrayList<>();
        }

        //该村户籍人口总数
        int hjzrs = 0;

        //该村接种人员数据
        int hjymjz = 0;

        //循环所有人判断当前总人数，该镇 户籍人口今日新增，该镇 户籍人口今日减少
        for (Czrk czrk : czrkList) {
            if (StringUtils.isNotEmpty(czrk.getVillageIdXjd()) && String.valueOf(czrk.getVillageIdXjd()).equals(areaId)) {
                if ("1".equals(czrk.getStatus())) {
                    hjzrs++;
                }

                if ("Y".equals(czrk.getIsNucleicAcid())) {
                    hjymjz++;
                }
            }
        }
        result.put("hjzrs", hjzrs);
        result.put("hjymjz", hjymjz);
        result.put("hjbfb", NumberUtils.percent(hjymjz, hjzrs));
        result.put("name", deptName);

        towsDataList.add(result);
        resultsC.put("townDatas", towsDataList);
        resultsC.put("type", "3");
        redisService.setCacheObject(areaId, resultsC);
    }

    public void upStarTime(String starTim) {
        redisService.setCacheObject("startTime", starTim);
    }

    public void upToQianShanStartTime(String starTime) {
        redisService.setCacheObject("toQianShanStartTime", starTime);
    }

    /**
     * 新增
     *
     * @param accountingDataList
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRES_NEW)
    @Master
    public int insertAccountingData(List<AccountingDataVo> accountingDataList) {
        SqlSession sqlSession = sqlSessionFactory.openSession(ExecutorType.BATCH, false);
        AccountingDataMapper mapper = sqlSession.getMapper(AccountingDataMapper.class);

        System.out.println("batchInsert 插入开始========");
        long start = System.currentTimeMillis();
        Czrk czrk = new Czrk();

        for (AccountingDataVo accountingData : accountingDataList) {
            String zjhm = accountingData.getZjhm();
            if (StringUtils.isNotBlank(zjhm)) {
                czrk.setIdCard(zjhm);
                czrk.setNucleicAcidTime(accountingData.getCjsj());
                //去更新常住人口表中数据
                czrkMapper.updateCzrkByNucleicAcid(czrk);
            }
            //先查询库里是否有相同数据
            int num = accountingDataMapper.selectRepeat(accountingData);
            if (num > 0) {
                continue;
            }
            int result = mapper.selectById(accountingData);
            if (result == 0) {
                if (accountingData.getCjssxq().contains("梅城镇")) {
                    accountingData.setCjqxqh("340882100000");
                } else if (accountingData.getCjssxq().contains("源潭镇")) {
                    accountingData.setCjqxqh("340882101000");
                } else if (accountingData.getCjssxq().contains("黄铺镇")) {
                    accountingData.setCjqxqh("340882104000");
                } else if (accountingData.getCjssxq().contains("王河镇")) {
                    accountingData.setCjqxqh("340882103000");
                } else if (accountingData.getCjssxq().contains("余井镇")) {
                    accountingData.setCjqxqh("340882102000");
                } else if (accountingData.getCjssxq().contains("官庄镇")) {
                    accountingData.setCjqxqh("340882107000");
                } else if (accountingData.getCjssxq().contains("槎水镇")) {
                    accountingData.setCjqxqh("340882105000");
                } else if (accountingData.getCjssxq().contains("水吼镇")) {
                    accountingData.setCjqxqh("340882106000");
                } else if (accountingData.getCjssxq().contains("塔畈乡")) {
                    accountingData.setCjqxqh("340882200000");
                } else if (accountingData.getCjssxq().contains("油坝乡")) {
                    accountingData.setCjqxqh("340882201000");
                } else if (accountingData.getCjssxq().contains("黄泥镇")) {
                    accountingData.setCjqxqh("340882108000");
                } else if (accountingData.getCjssxq().contains("天柱山镇")) {
                    accountingData.setCjqxqh("340882110000");
                } else if (accountingData.getCjssxq().contains("龙潭乡")) {
                    accountingData.setCjqxqh("340882202000");
                } else if (accountingData.getCjssxq().contains("黄柏镇")) {
                    accountingData.setCjqxqh("340882109000");
                } else if (accountingData.getCjssxq().contains("痘姆乡")) {
                    accountingData.setCjqxqh("340882203000");
                } else if (accountingData.getCjssxq().contains("五庙乡")) {
                    accountingData.setCjqxqh("340882204000");
                } else if (accountingData.getCjssxq().contains("开发区")) {
                    accountingData.setCjqxqh("340882400000");
                } else if (accountingData.getCjssxq().contains("lis")) {
                    accountingData.setCjqxqh("123456789");
                } else if (accountingData.getCjssxq().contains("高铁高速口")) {
                    accountingData.setCjqxqh("0123456789");
                } else if (accountingData.getCjssxq().contains("便民检测点")) {
                    accountingData.setCjqxqh("1258965412");
                } else {
                    accountingData.setCjqxqh("340882000000");
                }
                accountingData.setId(IdUtils.simpleUUID());
                mapper.insertAccountingData(accountingData);
            }
        }

        sqlSession.flushStatements();
        long end = System.currentTimeMillis();
        System.out.println("---------------插入核酸数据耗时" + (end - start) + "---------------");
        return 0;
    }


    /***
     * 来宜数据匹配(每个小时的35分开始跑数据)
     */
    @SneakyThrows
    //@Scheduled(cron = "0 35 * * * ? ")
    public void toQianshanData() {
        System.out.println("batchInsert 来宜人员插入开始========");
        long start = System.currentTimeMillis();

        String token = getToken();
        if (StringUtils.isNotBlank(token)) {

            //String startTime = redisService.getCacheObject("toQianShanStartTime");
            //if (StringUtils.isEmpty(startTime)) {
            //startTime = "2022-05-14 00:00:00";
            //}

            //数据库查询最新数据
            ToQianshanPersonner toQianshanPersonner = toQianshanPersonnerService.getNewInfo();
            String startTime = "2022-05-1 00:00:00";
            if (toQianshanPersonner != null) {
                startTime = toQianshanPersonner.getHiDate();
            }

            SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = df.parse(startTime);
            date.setTime(date.getTime() + 1000);
            startTime = df.format(date);


            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("client_id", "acdf50bd13be4901b64c62b1fee862c0");
            paramMap.put("access_token", token);
            paramMap.put("rc", "");
            paramMap.put("area", "潜山");

            String endTime = DateUtils.formatString(new Date());
            //redisService.setCacheObject("toQianShanStartTime", endTime);
            endTime = endTime.replace(" ", "%20");
            startTime = startTime.replace(" ", "%20");
            paramMap.put("djsjqs", startTime);
            paramMap.put("djsjjs", endTime);
            String http = "http://60.171.171.235:9090/service/api/rkk/qslyrysj";
            try {
                String data = HttpClientUtils.doGet(http, paramMap);

                if (StringUtils.isNotBlank(data)) {
                    List<ToQianshanPersonner> list = JSONObject.parseArray(data, ToQianshanPersonner.class);
                    if (list != null && list.size() > 0) {
                        //插入数据
                        toQianshanPersonnerService.insertToQianshanPersonner(list);
                    }
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        long end = System.currentTimeMillis();
        System.out.println("---------------插入来宜人员数据耗时" + (end - start) + "---------------");
    }

    public String test() {
        Long gjzwfwpt_rtime = new Date().getTime();
        System.out.println("时间戳------" + gjzwfwpt_rtime);
        String gjzwfwpt_rid = "TE3400003400000001@f6eae674bdc840d2b0474dd3d736faf1";
        String gjzwfwpt_sid = "s_X01201000200000000_4817";

        StringBuilder sb = new StringBuilder();
        sb.append(gjzwfwpt_sid).append(gjzwfwpt_rid).append(String.valueOf(gjzwfwpt_rtime));

        // System.out.println(sign(sid+rid+rtime,"90f27130802db6f63edb783831bf5aff"));
        System.out.println("加密------" + AESUtil.sign(sb.toString(), "e72f935d839db74e407ca9fa13cc78b7"));

        String gjzwfwpt_sign = AESUtil.sign(sb.toString(), "e72f935d839db74e407ca9fa13cc78b7");

        JSONObject paramMap = new JSONObject();
        paramMap.put("gjzwfwpt_rid", gjzwfwpt_rid);
        paramMap.put("gjzwfwpt_sid", gjzwfwpt_sid);
        paramMap.put("gjzwfwpt_rtime", String.valueOf(gjzwfwpt_rtime));
        paramMap.put("gjzwfwpt_sign", gjzwfwpt_sign);
        String http = "http://59.255.22.70:8443/authz/authSystem/getAppSecret";
        BufferedReader in = null;
        String response = "";
        try {
            String data = HttpClientUtils.send(http, paramMap, "utf-8");
            System.out.println("/authSystem/getAppSecret返回值------" + data);
            JSONObject jsonObject = JSONObject.parseObject(data);
            Map<String, Object> map = (Map<String, Object>) jsonObject.get("data");
            System.out.println("secret------" + (String) map.get("secret"));
            //秘钥 24小时有效
            String appsecret = AESUtil.AESDncode("e72f935d839db74e407ca9fa13cc78b7", (String) map.get("secret"));
            System.out.println("解密------" + appsecret);
            //根据秘钥获得最终签名
            gjzwfwpt_sign = AESUtil.sign(sb.toString(), appsecret);

            //请求url
            URL postUrl = new URL("http://59.255.22.70:8443/gateway/wsproxy");
            //请求参数map
            Map<String, String> postParams = new HashMap<String, String>();
            //组装参数
            //公共请求参数
            postParams.put("access_key", "TE3400003400000001@f6eae674bdc840d2b0474dd3d736faf1");
            postParams.put("format", "json");
            postParams.put("request_id", "");
            postParams.put("sign", gjzwfwpt_sign);
            postParams.put("timestamp", String.valueOf(gjzwfwpt_rtime));
            postParams.put("version", "1.0");
            //请求查询条件参数
            Map<String, String> params = new HashMap<String, String>();
            params.put("cert_num_man", "340826199601121171");
            params.put("name_man", "叶飞翔");
            StringBuilder biz_content = new StringBuilder("{");
            for (String key : params.keySet()) {
                String value = params.get(key);
                biz_content.append("\"" + key + "\"" + ":" + "\"" + value + "\",");
            }
            biz_content.deleteCharAt(biz_content.length() - 1);
            biz_content.append("}");
            postParams.put("biz_content", biz_content.toString());
            StringBuilder postData = new StringBuilder();
            for (Map.Entry<String, String> param : postParams.entrySet()) {
                if (postData.length() != 0) {
                    postData.append('&');
                }
                postData.append(param.getKey());
                postData.append("=");
                postData.append(param.getValue());
            }
            System.out.println("http://59.255.22.70:8443/gateway/wsproxy参数" + postData.toString());
            byte[] postDataBytes = postData.toString().getBytes(StandardCharsets.UTF_8);
            HttpURLConnection conn = (HttpURLConnection) postUrl.openConnection();
            conn.setDoOutput(true);
            conn.setDoInput(true);
            conn.setRequestMethod("POST");
            conn.setRequestProperty("connection", "Keep-Alive");
            conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            conn.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
            conn.setRequestProperty("Content-Length", String.valueOf(postDataBytes.length));
            conn.connect();
            OutputStreamWriter out = new OutputStreamWriter(conn.getOutputStream(), "utf-8");
            out.write(postData.toString());
            // flush输出流的缓冲
            out.flush();
            // 定义BufferedReader输入流来读取URL的响应
            int responseCode = conn.getResponseCode();
            System.out.println("状态码:" + responseCode);
            InputStreamReader raw = null;
            if (responseCode == 200) {
                InputStream is = conn.getInputStream();
                raw = new InputStreamReader(is, StandardCharsets.UTF_8);
            } else {
                InputStream errorStream = conn.getErrorStream();
                raw = new InputStreamReader(errorStream, StandardCharsets.UTF_8);
            }
            in = new BufferedReader(raw);
            StringBuilder sb1 = new StringBuilder();
            for (int c; (c = in.read()) >= 0; ) {
                sb1.append((char) c);
            }
            //获取查询结果，结果示例见第5条，
            response = sb1.toString();
            System.out.println("结果------" + response);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
        //使用finally块来关闭输出流、输入流
        finally {
            try {
                if (in != null) {
                    in.close();
                }
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }
        return response;
    }
}
