package com.boman.web.core.service.accounting;
/**
 * @author tjf
 * @Date: 2022/05/13/11:14
 */

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.boman.common.core.exception.BaseException;
import com.boman.common.core.utils.DateUtils;
import com.boman.common.core.utils.StringUtils;
import com.boman.common.core.utils.sql.SqlUtil;
import com.boman.common.core.web.page.PageDomain;
import com.boman.common.core.web.page.TableSupport;
import com.boman.common.datasource.annotation.Slave;
import com.boman.domain.Czrk;
import com.boman.domain.SysUser;
import com.boman.domain.dto.AjaxResult;
import com.boman.system.api.RemoteDeptService;
import com.boman.web.core.domain.TSampling514;
import com.boman.web.core.domain.vo.AccountingDataVo;
import com.boman.web.core.mapper.AccountingDataMapper;
import com.boman.web.core.mapper.CzrkMapper;
import com.boman.web.core.mapper.TSampling514Mapper;
import com.boman.web.core.service.TaskService;
import com.boman.web.core.utils.AuthUtils;
import com.boman.web.core.utils.CzrkUtils;
import com.boman.web.core.wst.WstRestClient;
import com.github.pagehelper.PageHelper;
import com.iflytek.wst.gateway.sdk.constant.SdkConstant;
import com.iflytek.wst.gateway.sdk.model.ApiResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;

import static com.boman.web.core.utils.CzrkUtils.setQueryRole;
import static com.boman.web.core.utils.CzrkUtils.setQueryRoleJcd;

/**
 * @author tjf
 * @Date: 2022/05/13/11:14
 */
@Service
@Slf4j
public class AccountingDataServiceImpl implements IAccountingDataService {

    @Resource
    private AccountingDataMapper accountingDataMapper;
    @Resource
    private RemoteDeptService remoteDeptService;

    @Resource
    private SqlSessionFactory sqlSessionFactory;

    @Resource
    private CzrkMapper czrkMapper;

    @Resource
    private TSampling514Mapper TSampling514Mapper;

    @Resource
    TaskService taskService;


    /***
     *  潜山核酸数据列表页(根据检测点)
     * @return
     */
    @Override
    public List<AccountingDataVo> nucleicAcidJcd(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        //权限判断
        setQueryRoleJcd(accountingData, sysUser);
        startPage();
        List<AccountingDataVo> list = accountingDataMapper.nucleicAcidJcd(accountingData);
        return list;
    }

    @Override
    public AjaxResult detailedJcd(String id) {
        if(StringUtils.isEmpty(id)){
            return AjaxResult.error("参数错误");
        }
        AccountingDataVo accountingDataVo = accountingDataMapper.detailedJcd(id);
        return AjaxResult.success("访问成功",accountingDataVo);
    }

    @Override
    public List<AccountingDataVo> exportHsd(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        setQueryRoleJcd(accountingData, sysUser);
        List<AccountingDataVo> list = accountingDataMapper.nucleicAcidJcd(accountingData);
        if (list == null || list.size() <= 0) {
            throw new BaseException("请下载属于本乡镇数据");
        }
        if(list.size()>150000){
            throw new BaseException("文件过大，到处失败，请分批导出");
        }
        return list;
    }

    @Override
    public List<AccountingDataVo> nucleicAcidZd(AccountingDataVo accountingData) {
        accountingData.setCjqxqh("0123456789");
        List<AccountingDataVo> list = accountingDataMapper.nucleicAcidZd(accountingData);
        return list;
    }

    @Override
    public List<AccountingDataVo> exportZd(AccountingDataVo accountingData) {
        accountingData.setCjqxqh("0123456789");
        List<AccountingDataVo> list = accountingDataMapper.nucleicAcidZd(accountingData);
        if(list.size()>150000){
            throw new BaseException("文件过大，到处失败，请分批导出");
        }
        return list;
    }

    /**
     * 潜山核酸数据列表页(户籍地址)
     *
     * @param accountingData
     * @return
     */
    @Override
    public List<AccountingDataVo> nucleicAcidHJList(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        log.info("{}于{}查询核酸户籍人口列表，查询条件：{}"
                , sysUser.getUserName(), DateUtils.dateTimeNow(), JSON.toJSONString(accountingData));
        //获取时段
        String timeSlot = accountingData.getTimeSlot();
        if (StringUtils.isNotBlank(timeSlot)) {
            //开始时间
            String startTime = DateUtils.minusDayOfDate(Integer.parseInt(timeSlot));
            Date endTime = DateUtils.getNowDate();
            Map<String, Object> map = new HashMap<>();
            map.put("startTime", startTime);
            map.put("endTime", endTime);
            accountingData.setParams(map);
        }

        //设置查询列表权限
        setQueryRole(accountingData, sysUser, Czrk.HJ);
        startPage();
        List<AccountingDataVo> list = new ArrayList<>();
        if (StringUtils.isNotEmpty(accountingData.getIsNucleicAcid()) && "N".equals(accountingData.getIsNucleicAcid())) {
            //查询户籍未做核酸人员
            list = accountingDataMapper.selectNoAccountingDataHjList(accountingData);
            for (AccountingDataVo accountingDataVo : list) {
                accountingDataVo.setIsNucleicAcid("N");
            }
        } else {
            list = accountingDataMapper.selectAccountingDataHjList(accountingData);
            for (AccountingDataVo accountingDataVo : list) {
                accountingDataVo.setIsNucleicAcid("Y");
            }
        }

        CzrkUtils.packAddrNucleicAcid(list);
        return list;
    }

    /**
     * 潜山核酸数据列表页(居住地址)
     *
     * @param accountingData
     * @return
     */
    @Override
    public List<AccountingDataVo> nucleicAcidJzdzList(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        log.info("{}于{}查询核酸居住人口列表，查询条件：{}"
                , sysUser.getUserName(), DateUtils.dateTimeNow(), JSON.toJSONString(accountingData));
        //获取时段
        String timeSlot = accountingData.getTimeSlot();
        if (StringUtils.isNotBlank(timeSlot)) {
            //开始时间
            String startTime = DateUtils.minusDayOfDate(Integer.parseInt(timeSlot));
            Date endTime = DateUtils.getNowDate();
            Map<String, Object> map = new HashMap<>();
            map.put("startTime", startTime);
            map.put("endTime", endTime);
            accountingData.setParams(map);
        }
        //设置查询列表权限
        setQueryRole(accountingData, sysUser, Czrk.CZ);
        startPage();
        List<AccountingDataVo> list = new ArrayList<>();
        if (StringUtils.isNotEmpty(accountingData.getIsNucleicAcid()) && "N".equals(accountingData.getIsNucleicAcid())) {
            //查询户籍未做核酸人员
            list = accountingDataMapper.selectNoAccountingDataJzdzList(accountingData);
            for (AccountingDataVo accountingDataVo : list) {
                accountingDataVo.setIsNucleicAcid("N");
            }
        } else {
            list = accountingDataMapper.selectAccountingDataJzdzList(accountingData);
            for (AccountingDataVo accountingDataVo : list) {
                accountingDataVo.setIsNucleicAcid("Y");
            }
        }

        CzrkUtils.packAddrNucleicAcid(list);
        return list;
    }

    private void startPage() {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        if (StringUtils.isNotNull(pageNum) && StringUtils.isNotNull(pageSize)) {
            String orderBy = SqlUtil.escapeOrderBySql(pageDomain.getOrderBy());
            PageHelper.startPage(pageNum, pageSize, orderBy);
        }
    }


    @Override
    public AjaxResult detailedInfo(AccountingDataVo accountingData) {
        List<AccountingDataVo> accountingDataVoList = accountingDataMapper.detailedInfoByIdCard(accountingData);
        CzrkUtils.packAddrNucleicAcid(accountingDataVoList);
        return AjaxResult.success(accountingDataVoList.get(0));
    }

    /***
     * 对外万事通开放接口
     * 根据身份证号去查询核酸检测列表
     */
    @Override
    public AjaxResult wanShiTongList(AccountingDataVo accountingData) {

        //通过token获取信息
        ApiResponse response = WstRestClient.getInstance().getUserInfoByToken(accountingData.getToken());

        int code = response.getCode();
        if(code!=200 || response.getBody() == null){
            return AjaxResult.error("参数错误");
        }

        String ResultBody = new String(response.getBody(), SdkConstant.CLOUDAPI_ENCODING);
        Map maps = (Map)JSON.parse(ResultBody);
        JSONObject data = (JSONObject)maps.get("data");
        String idCard = (String) data.get("perUserVo.credentNo");
        if (StringUtils.isEmpty(idCard)){
            return AjaxResult.error("参数错误");
        }
        accountingData.setZjhm(idCard);
        //获取当前时间
        Date data1 = DateUtils.getNowDate();
        String endTime = DateUtils.formatString(data1);
        //当前时间往前推20天
        String startTime = DateUtils.minusDayOfDate(20);
        Map<String, Object> params = new HashMap<>();
        params.put("startTime",startTime);
        params.put("endTime",endTime);
        accountingData.setParams(params);

        List<AccountingDataVo> accountingDataVos = accountingDataMapper.selectWanShiTongList(accountingData);
        return AjaxResult.success(accountingDataVos);
    }
    /***
     * 对外万事通开放接口
     * 根据身份证号和检测时间去查询核酸检测详情
     */
    @Override
    public AjaxResult wanShiTongInfo(AccountingDataVo accountingData) {
        AccountingDataVo accountingDataVo = accountingDataMapper.selectWanShiTongInfo(accountingData);
        return AjaxResult.success(accountingDataVo);
    }


    /**
     * 核酸数据导出(户籍)
     *
     * @param accountingData
     * @throws IOException
     */
    @Override
    public List<AccountingDataVo> getExportHj(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        //设置查询列表权限
        setQueryRole(accountingData, sysUser, Czrk.HJ);

        List<AccountingDataVo> accountingDataList = new ArrayList<>();
        if (StringUtils.isNotEmpty(accountingData.getIsNucleicAcid()) && "N".equals(accountingData.getIsNucleicAcid())) {
            //查询户籍未做核酸人员
            accountingDataList = accountingDataMapper.getExportHjNo(accountingData);
            for (AccountingDataVo accountingDataVo : accountingDataList) {
                accountingDataVo.setIsNucleicAcid("N");
            }
        } else {
            accountingDataList = accountingDataMapper.getExportHj(accountingData);
            for (AccountingDataVo accountingDataVo : accountingDataList) {
                accountingDataVo.setIsNucleicAcid("Y");
            }
        }
        CzrkUtils.packAddrNucleicAcid(accountingDataList);
        if (accountingDataList == null || accountingDataList.size() <= 0) {
            throw new BaseException("请下载属于本乡镇数据");
        }
        return accountingDataList;
    }

    /***
     * 核酸数据导出(常住)
     * @param accountingData
     * @return
     */
    @Override
    public List<AccountingDataVo> exportCz(AccountingDataVo accountingData) {
        SysUser sysUser = AuthUtils.getLoginUser().getSysUser();
        //设置查询列表权限
        setQueryRole(accountingData, sysUser, Czrk.CZ);

        List<AccountingDataVo> accountingDataList = new ArrayList<>();

        if (StringUtils.isNotEmpty(accountingData.getIsNucleicAcid()) && "N".equals(accountingData.getIsNucleicAcid())) {
            //查询户籍未做核酸人员
            accountingDataList = accountingDataMapper.exportCzjNo(accountingData);
            for (AccountingDataVo accountingDataVo : accountingDataList) {
                accountingDataVo.setIsNucleicAcid("N");
            }
        } else {
            accountingDataList = accountingDataMapper.exportCz(accountingData);
            for (AccountingDataVo accountingDataVo : accountingDataList) {
                accountingDataVo.setIsNucleicAcid("Y");
            }
        }


        CzrkUtils.packAddrNucleicAcid(accountingDataList);
        if (accountingDataList == null || accountingDataList.size() <= 0) {
            throw new BaseException("请下载属于本乡镇数据");
        }
        return accountingDataList;
    }

    @Override
    public int tongjiHjZ(String startTime, String endTime, String areaId) {
        return accountingDataMapper.tongjiHjZ(startTime, endTime, areaId);
    }

    @Override
    public int tongjiCzZ(String startTime, String endTime, String areaId) {
        return accountingDataMapper.tongjiCzZ(startTime, endTime, areaId);
    }

    @Override
    public AccountingDataVo getAccountingDataOne() {
        return accountingDataMapper.getAccountingDataOne();
    }

    @Override
    public List<AccountingDataVo> getAllData() {
        return accountingDataMapper.getAllData();
    }

    @Override
    public List<TSampling514> getTSampling514AllData(String startTime, String endTime) {
        return TSampling514Mapper.getTSampling514AllData(startTime, endTime);
    }

    @Override
    public List<TSampling514> getTSampling514AllDataNoTime() {
        return TSampling514Mapper.getTSampling514AllDataNoTime();
    }

    /**
     * 从第三方库获取核酸数据
     */
    @Slave
    @Override
    public void thirdNucleicAcid(String startTime, String endTime) {
        System.out.println("batchInsert 查询数据开始========");
        long start1 = System.currentTimeMillis();
        List<AccountingDataVo> accountingDataVos = accountingDataMapper.thirdNucleicAcid(startTime, endTime);
        if (accountingDataVos != null) {
            taskService.insertAccountingData(accountingDataVos);
        }
        long end1 = System.currentTimeMillis();
        System.out.println("---------------查询数据耗时" + (end1 - start1) + "---------------");
    }
}
