package com.boman.web.core.utils;


import cn.hutool.extra.spring.SpringUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.boman.common.core.utils.StringUtils;
import com.boman.common.redis.service.RedisService;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.concurrent.TimeUnit;
/**
 * 签名工具类
 * @author 86150
 *
 */
@Component
public class GjzwfwptSignUtil {

	@Resource
	private RedisService redisService;

	private static GjzwfwptSignUtil gjzwfwptSignUtil;

	@PostConstruct
	public void init(){
		gjzwfwptSignUtil= this;
		gjzwfwptSignUtil.redisService = this.redisService;
	}



	/**
	 * 获取签名
	 * 1、sid+rid+rtime+appkey 加密生成gjzwfwpt_sign
	 * 2、sid+rid+rtime+sign TOKENURL 获取appsecret
	 * 3、使用解密示例代码，用appkey对appsecret进行解密
	 * 4、将appkey换成步骤三解密后的字符串，重复步骤一，获取最终gjzwfwpt_sign；
	 * @param sid
	 * @param rid
	 * @param appkey
	 * @return
	 */
	public static String getGjzwfwptSign(String sid, String rid,
			String appkey) {

		String gjzwfwpt_sign = gjzwfwptSignUtil.redisService.getCacheObject(appkey + ":gjzwfwpt_sign");
		if (StringUtils.isEmpty(gjzwfwpt_sign)) {
			// 1、sid+rid+rtime+appkey 加密生成gjzwfwpt_sign
			Long rtime = System.currentTimeMillis();
			System.out.println("时间戳rtime-"+rtime);
			String content = sid + rid + rtime; // 内容拼接
			System.out.println("拼接内容-"+content);
			String sign = AESUtil.sign(content, appkey); // 获取签名
			boolean verifyFlag = AESUtil.verifySign(content, appkey, sign); // 签名验证
			if (verifyFlag) {
				// 2、sid+rid+rtime+sign TOKENURL 获取appsecret
				JSONObject params = new JSONObject();
				params.put("gjzwfwpt_rid", rid);
				params.put("gjzwfwpt_sid", sid);
				params.put("gjzwfwpt_rtime", rtime);
				params.put("gjzwfwpt_sign", sign);
				String http = "http://59.255.22.70:8443/authz/authSystem/getAppSecret";
				String result = HttpRequest.post(http)
						.body(params.toJSONString())
						.timeout(20000)//超时，毫秒
						.execute().body();
				JSONObject resultObj = JSONObject.parseObject(result);
				String code = resultObj.getString("code");
				if ("0".equals(code)) {
					// 3、使用解密示例代码，用appkey对appsecret进行解密
					JSONObject dataObj = resultObj.getJSONObject("data");
					String secret = dataObj.getString("secret");
					String appsecret = AESUtil.AESDncode(appkey, secret);
					// 4、将appkey换成步骤三解密后的字符串，重复步骤一，获取最终gjzwfwpt_sign；
					if (appsecret != null) {
						gjzwfwpt_sign = AESUtil.sign(content, appsecret);
					}
					// Tips：gjzwfwpt_sign有效期10分钟
					System.out.println("gjzwfwpt_sign---toString"+rtime.toString());
					System.out.println("gjzwfwpt_sign-"+String.valueOf(rtime));
					gjzwfwptSignUtil.redisService.setCacheObject(appkey + ":gjzwfwpt_sign",gjzwfwpt_sign, 600L, TimeUnit.SECONDS );
					gjzwfwptSignUtil.redisService.setCacheObject(appkey + ":gjzwfwpt_rtime",String.valueOf(rtime), 600L, TimeUnit.SECONDS);
					System.out.println("最终签名"+gjzwfwpt_sign);
					return gjzwfwpt_sign;
				} else {
					System.out.println("resultObj:" + resultObj.toString());
				}
			} else {
				System.out.println("签名错误，验证签名失败");
			}
		}
		return gjzwfwpt_sign;
	}
	
	public static String getGjzwfwptRtime(String appkey) {
		String gjzwfwpt_rtime = gjzwfwptSignUtil.redisService.getCacheObject(appkey + ":gjzwfwpt_rtime");
		System.out.println(gjzwfwpt_rtime);
		return gjzwfwpt_rtime;
	}


}
